#[repr(u8)]pub enum PhyHalf {
STANDARD = 0,
HALF_RATE = 1,
}Variants
STANDARD = 0
Standard half rate sampling. The clock to the DMIC is sent at the same rate as the decimator is providing.
HALF_RATE = 1
Use half rate sampling. The clock to the DMIC is sent at half the rate as the decimator is providing.
Implementations